==> junta-0.2.14.tar.gz: junta-0.2.14/server/junta_xml.py <==
#!/usr/bin/env python
# coding: utf-8

"""
sudo cp junta_xml.py /usr/bin/junta_to_xml
sudo cp junta_xml.py /usr/bin/junta_from_xml

Использование:
cat <имя файла> | junta_to_xml
junta_to_xml <имя файла> 
junta_to_xml <имя входного файла> <имя выходного файла>
"""

import sys

dictionary_to_replace = {'<': '&gt;', '>': '&lt;', '\'': '&apos;', '\"': '&quot;'}

def replace_from_xml(content):
    new_content = content
    for val, key in dictionary_to_replace.items():
        new_content = new_content.replace(key, val);
    return new_content.replace('&amp;', '&');

def replace_to_xml(content):
    new_content = content.replace('&', '&amp;');
    for key, val in dictionary_to_replace.items():
        new_content = new_content.replace(key, val);
    return new_content

def cycle(replace, input_thread=sys.stdin, output_thread=sys.stdout):
    if replace is None:
        print 'Error. Bad file name. \nRename this file to junta_to_xml or junta_from_xml'
        return
    in_cmd = False
    while True:
        line = input_thread.readline()
        if not line:
            break
        
        start = 0
        stop = len(line) - 1 
        if "<Cmd>" in line:
            in_cmd = True
            start = line.find('<Cmd>') + 5
            
        if not in_cmd:
            stop = 0
                    
        if "</Cmd>" in line:
            in_cmd = False
            stop = line.find('</Cmd>')
        
        output_thread.write("".join([line[:start], replace(line[start:stop]), line[stop:],]))
        output_thread.flush()

def preprocessor(content, direction=True):
    """ Препроцессор для рецептов. (используется в коде сервера)
        Если direction == True, то это из текста в xml (при вводе рецепта),
        Если direction == False, то это из xml в текст (при выводе рецепта)
    """
    result = []
    
    if direction:   replace = replace_to_xml
    else:           replace = replace_from_xml
    
    in_cmd = False
    lines = content.split('\n')
    for line in lines:     
        start = 0
        stop = len(line) - 1 
        if "<Cmd>" in line:
            in_cmd = True
            start = line.find('<Cmd>') + 5
            
        if not in_cmd:
            stop = 0
                    
        if "</Cmd>" in line:
            in_cmd = False
            stop = line.find('</Cmd>')
        
        result.append("".join([line[:start], replace(line[start:stop]), line[stop:],]))
    return "\n".join(result)

if __name__ == '__main__':
    input_thread=sys.stdin
    output_thread=sys.stdout
    if 'to_xml' in sys.argv[0]:
        replace = replace_to_xml
    elif 'from_xml' in sys.argv[0]:
        replace = replace_from_xml
    else:
        replace = None
        
    if len(sys.argv) > 2:
        cycle(replace, open(sys.argv[1], 'r'), open(sys.argv[2], 'w'))
    elif len(sys.argv) > 1:
        cycle(replace, open(sys.argv[1], 'r'))
    else:
        cycle(replace)

==> junta-0.2.18.tar.gz: junta-0.2.18/server/junta_xml.py <==
#!/usr/bin/env python
# coding: utf-8

"""
sudo cp junta_xml.py /usr/bin/junta_to_xml
sudo cp junta_xml.py /usr/bin/junta_from_xml

Использование:
cat <имя файла> | junta_to_xml
junta_to_xml <имя файла> 
junta_to_xml <имя входного файла> <имя выходного файла>
"""

import sys

dictionary_to_replace = {'>': '&gt;', '<': '&lt;', '\'': '&apos;', '\"': '&quot;'}

def replace_from_xml(content):
    new_content = content
    for val, key in dictionary_to_replace.items():
        new_content = new_content.replace(key, val);
    return new_content.replace('&amp;', '&');

def replace_to_xml(content):
    new_content = content.replace('&', '&amp;');
    for key, val in dictionary_to_replace.items():
        new_content = new_content.replace(key, val);
    return new_content

def cycle(replace, input_thread=sys.stdin, output_thread=sys.stdout):
    if replace is None:
        print 'Error. Bad file name. \nRename this file to junta_to_xml or junta_from_xml'
        return
    in_cmd = False
    while True:
        line = input_thread.readline()
        if not line:
            break
        
        start = 0
        stop = len(line) - 1 
        if "<Cmd>" in line:
            in_cmd = True
            start = line.find('<Cmd>') + 5
            
        if not in_cmd:
            stop = 0
                    
        if "</Cmd>" in line:
            in_cmd = False
            stop = line.find('</Cmd>')
        
        output_thread.write("".join([line[:start], replace(line[start:stop]), line[stop:],]))
        output_thread.flush()

def preprocessor(content, direction=True):
    """ Препроцессор для рецептов. (используется в коде сервера)
        Если direction == True, то это из текста в xml (при вводе рецепта),
        Если direction == False, то это из xml в текст (при выводе рецепта)
    """
    result = []
    
    if direction:   replace = replace_to_xml
    else:           replace = replace_from_xml
    
    in_cmd = False
    lines = content.split('\n')
    for line in lines:     
        start = 0
        stop = len(line) - 1 
        if "<Cmd>" in line:
            in_cmd = True
            start = line.find('<Cmd>') + 5
            
        if not in_cmd:
            stop = 0
                    
        if "</Cmd>" in line:
            in_cmd = False
            stop = line.find('</Cmd>')
        
        result.append("".join([line[:start], replace(line[start:stop]), line[stop:],]))
    return "\n".join(result)

if __name__ == '__main__':
    input_thread=sys.stdin
    output_thread=sys.stdout
    if 'to_xml' in sys.argv[0]:
        replace = replace_to_xml
    elif 'from_xml' in sys.argv[0]:
        replace = replace_from_xml
    else:
        replace = None
        
    if len(sys.argv) > 2:
        cycle(replace, open(sys.argv[1], 'r'), open(sys.argv[2], 'w'))
    elif len(sys.argv) > 1:
        cycle(replace, open(sys.argv[1], 'r'))
    else:
        cycle(replace)
